@@ -101,12 +101,12 @@ func lbWaitCommand() *core.Command {
 func lbCreateBuilder(c *core.Command) *core.Command {
 	c.ArgSpecs.GetByName("type").EnumValues = typesList
 	c.ArgSpecs.GetByName("type").Default = core.DefaultValueSetter("LB-S")
-	c.ArgSpecs.GetByName("type").ValidateFunc = func(argSpec *core.ArgSpec, value interface{}) error {
+	c.ArgSpecs.GetByName("type").ValidateFunc = func(_ *core.ArgSpec, _ interface{}) error {
 		// Allow all lb types
 		return nil
 	}
 
-	c.WaitFunc = func(ctx context.Context, argsI, respI interface{}) (interface{}, error) {
+	c.WaitFunc = func(ctx context.Context, _, respI interface{}) (interface{}, error) {
 		api := lb.NewZonedAPI(core.ExtractClient(ctx))
 		return api.WaitForLb(&lb.ZonedAPIWaitForLBRequest{
 			LBID:          respI.(*lb.LB).ID,
@@ -125,7 +125,7 @@ var typesList = []string{
 
 func lbMigrateBuilder(c *core.Command) *core.Command {
 	c.ArgSpecs.GetByName("type").EnumValues = typesList
-	c.ArgSpecs.GetByName("type").ValidateFunc = func(argSpec *core.ArgSpec, value interface{}) error {
+	c.ArgSpecs.GetByName("type").ValidateFunc = func(_ *core.ArgSpec, _ interface{}) error {
 		// Allow all lb types
 		return nil
 	}
@@ -164,22 +164,28 @@ func lbGetStatsBuilder(c *core.Command) *core.Command {
 
 func interceptLB() core.CommandInterceptor {
 	return func(ctx context.Context, argsI interface{}, runner core.CommandRunner) (interface{}, error) {
+		var getLB *lb.LB
+		var err error
+
 		client := core.ExtractClient(ctx)
 		api := lb.NewZonedAPI(client)
 
+		if _, ok := argsI.(*lb.ZonedAPIDeleteLBRequest); ok {
+			getLB, err = api.GetLB(&lb.ZonedAPIGetLBRequest{
+				Zone: argsI.(*lb.ZonedAPIDeleteLBRequest).Zone,
+				LBID: argsI.(*lb.ZonedAPIDeleteLBRequest).LBID,
+			})
+			if err != nil {
+				return nil, err
+			}
+		}
+
 		res, err := runner(ctx, argsI)
 		if err != nil {
 			return nil, err
 		}
 
 		if _, ok := res.(*core.SuccessResult); ok {
-			getLB, err := api.GetLB(&lb.ZonedAPIGetLBRequest{
-				Zone: argsI.(*lb.ZonedAPIDeleteLBRequest).Zone,
-				LBID: argsI.(*lb.ZonedAPIDeleteLBRequest).LBID,
-			})
-			if err != nil {
-				return nil, err
-			}
 			if len(getLB.Tags) != 0 && getLB.Tags[0] == kapsuleTag {
 				return warningKapsuleTaggedMessageView(), nil
 			}
